=======================================
Sample ASR1000 L3 Router Service Plugin
=======================================

L3 Router Service Plugin
~~~~~~~~~~~~~~~~~~~~~~~~
The sample configuration below for the L3 router service plugin can also be
viewed as raw text
:download:`cisco_router_plugin.ini <../../../../etc/neutron/plugins/cisco/cisco_router_plugin.ini>`
file.

.. literalinclude:: ../../../../etc/neutron/plugins/cisco/cisco_router_plugin.ini

Device Manager Plugin
~~~~~~~~~~~~~~~~~~~~~
The sample configuration below for the device manager plugin can also be
viewed as raw text
:download:`cisco_device_manager_plugin.ini <../../../../etc/neutron/plugins/cisco/cisco_device_manager_plugin.ini>`
file.

.. literalinclude:: ../../../../etc/neutron/plugins/cisco/cisco_device_manager_plugin.ini

Configuration Agent
~~~~~~~~~~~~~~~~~~~
The sample configurations below for the configuration agent can also be viewed
as raw text
:download:`cisco_cfg_agent.ini <../../../../etc/neutron/plugins/cisco/cisco_cfg_agent.ini>`
file.

.. literalinclude:: ../../../../etc/neutron/plugins/cisco/cisco_cfg_agent.ini
